@@ -102,7 +102,7 @@ class Initialization(seamm.Node):
 
         return self.header + '\n' + __(text, **P, indent=4 * ' ').__str__()
 
-    def get_input(self):
+    def get_input(self, extras=None):
         """Get the input for the initialization of LAMMPS"""
 
         self.description = []
@@ -202,6 +202,23 @@ class Initialization(seamm.Node):
         if nonbond_term == 'nonbond(9-6)':
             pair_style_base = 'lj/class2'
             mixing = 'sixthpower'
+        elif nonbond_term == 'nonbond(12-6)':
+            pair_style_base = 'lj/cut'
+            # What type of mixing rule?
+            modifiers = ff.ff['modifiers']['nonbond(12-6)']
+            mixing = ''
+            for section in modifiers:
+                for item in modifiers[section]:
+                    if 'combination' in item:
+                        if mixing == '':
+                            mixing = item.split()[1]
+                        if mixing != item.split()[1]:
+                            raise RuntimeError(
+                                'Conflicting combination rules in '
+                                "nonbond(12-6) section '" + section + "'"
+                            )
+            if mixing == "":
+                mixing = 'geometric'
         else:
             raise RuntimeError(
                 "Can't handle nonbond term {} yet!".format(nonbond_term)
