@@ -214,7 +214,7 @@ class NPT(lammps_step.NVT):
 
         return next_node
 
-    def get_input(self):
+    def get_input(self, extras=None):
         """Get the input for an NPT dynamics run in LAMMPS"""
 
         keep_orthorhombic = True
@@ -427,10 +427,17 @@ class NPT(lammps_step.NVT):
                 )
             )
 
+        if extras is not None and 'shake' in extras:
+            nfixes += 1
+            lines.append(extras['shake'].format(nfixes))
+
+        lines.append('')
         lines.append('run                 {}'.format(nsteps))
         lines.append('')
+
         for fix in range(1, nfixes + 1):
             lines.append('unfix               {}'.format(fix))
+        lines.append('')
 
         return lines
 
